@@ -352,69 +352,74 @@ class HathiPreservation(models.Model):
     @transaction.atomic
     def import_data(url, bucket="", s3client=None):
         # download the data file from S3 bucket
-        hathi_data = utils.download_remote(
-            False, HathiPreservation, url,
-            bucket=bucket, s3client=s3client)
+        with tempfile.TemporaryDirectory() as tmp:
+            path = Path(tmp) / 'downloaded.file'
 
-        # clear out existing data
-        utils.clear_out(HathiPreservation)
+            hathi_data = utils.download_remote(False, HathiPreservation,
+                                               url, bucket=bucket,
+                                               s3client=s3client,
+                                               decode=False, file=True,
+                                               filename=str(path))
 
-        csv.field_size_limit(sys.maxsize)
+            # clear out existing data
+            utils.clear_out(HathiPreservation)
 
-        with StringIO(hathi_data) as input_file:
-            csv_reader = csv.reader(input_file, delimiter='\t')
+            csv.field_size_limit(sys.maxsize)
 
-            volume_matcher = r'v\.\s?(\d+(?:\-?\d+)?)'
-            no_matcher = r'no\.\s?(\d+(?:\-?\d+)?)'
-            year_matcher = r'\d{4}'
+            with open(str(path), 'r') as input_file:
+                csv_reader = csv.reader(input_file, delimiter='\t')
 
-            for row in csv_reader:
-                try:
-                    vols = row[4]
-                    issn = row[9]
-                    title = row[11]
-                    publishing_info = row[12]
-                    date = row[16]
-                    bf = row[19]
-                    unknown_format = False
+                volume_matcher = r'v\.\s?(\d+(?:\-?\d+)?)'
+                no_matcher = r'no\.\s?(\d+(?:\-?\d+)?)'
+                year_matcher = r'\d{4}'
 
-                    # if it's a serial, try to parse the vols
-                    if bf == 'SE' and issn and vols:
-                        matches = re.findall(volume_matcher, vols)
+                for row in csv_reader:
+                    try:
+                        vols = row[4]
+                        issn = row[9]
+                        title = row[11]
+                        publishing_info = row[12]
+                        date = row[16]
+                        bf = row[19]
+                        unknown_format = False
 
-                        if matches:
-                            for match in matches:
-                                vols = utils.unpack_range(match)
-                        else:
-                            matches = re.findall(no_matcher, vols)
+                        # if it's a serial, try to parse the vols
+                        if bf == 'SE' and issn and vols:
+                            matches = re.findall(volume_matcher, vols)
 
                             if matches:
                                 for match in matches:
                                     vols = utils.unpack_range(match)
                             else:
-
-                                matches = re.findall(year_matcher, vols)
+                                matches = re.findall(no_matcher, vols)
 
                                 if matches:
                                     for match in matches:
-                                        vols = match
+                                        vols = utils.unpack_range(match)
                                 else:
-                                    unknown_format = True
 
-                        if not unknown_format:
-                            if title.endswith('.'):
-                                title = title[:-1]
+                                    matches = re.findall(year_matcher, vols)
 
-                            HathiPreservation.objects.create(
-                                issn=issn,
-                                title=title,
-                                preserved_volumes=vols
-                            )
+                                    if matches:
+                                        for match in matches:
+                                            vols = match
+                                    else:
+                                        unknown_format = True
 
-                            logging.info(f'Added {title} to '
-                                         f'{HathiPreservation.name()} data')
-                except IndexError:
-                    pass
+                            if not unknown_format:
+                                if title.endswith('.'):
+                                    title = title[:-1]
+
+                                HathiPreservation.objects.create(
+                                    issn=issn,
+                                    title=title,
+                                    preserved_volumes=vols
+                                )
+
+                                logging.info(f'Added {title} to '
+                                             f'{HathiPreservation.name()} data')
+                    except IndexError:
+                        pass
 
 
 class PorticoPreservation(models.Model):
